@@ -10,6 +10,7 @@ from mercury_engine_data_structures.formats.brev import Brev
 from mercury_engine_data_structures.formats.brfld import Brfld
 from mercury_engine_data_structures.formats.brsa import Brsa
 from mercury_engine_data_structures.formats.pkg import Pkg
+from mercury_engine_data_structures.formats.toc import Toc
 
 ALL_FORMATS = {
     "PKG": Pkg,
@@ -21,6 +22,7 @@ ALL_FORMATS = {
     "BREM": Brem,
     "BRES": Bres,
     "BREV": Brev,
+    "TOC": Toc,
 }
 
 
