@@ -69,7 +69,7 @@ class TypeExporter:
                 key = "NONE"
             enum_definition += f'    {key} = {value}\n'
 
-        code = f"{enum_definition}\n\nconstruct_{type_variable} = construct.Enum(construct.Int32ul, {type_variable})"
+        code = f"{enum_definition}\n\nconstruct_{type_variable} = StrictEnum({type_variable})"
 
         return "construct_" + type_variable, code
 
@@ -108,8 +108,8 @@ class TypeExporter:
         return f'Object({field_var}{fields_def})'
 
     def _export_type(self, type_name: str):
-        type_variable = _type_name_to_python_identifier(type_name)
         type_data = self.all_types[type_name]
+        type_variable = type_data.name_as_python_identifier
 
         if isinstance(type_data, type_lib.PrimitiveType):
             type_variable = primitive_to_construct[type_data.primitive_kind]
@@ -181,6 +181,7 @@ from mercury_engine_data_structures import common_types
 from mercury_engine_data_structures.object import Object
 from mercury_engine_data_structures.pointer_set import PointerSet
 from mercury_engine_data_structures.formats.property_enum import PropertyEnum, PropertyEnumUnsafe
+from mercury_engine_data_structures.construct_extensions.enum import StrictEnum
 
 """
         seen_types_with_pointer = set()
